==> es-ar-2.26.zip: es-ar/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d archivos adjuntos';
L10n::$locales['%d comments'] = '%d comentarios';
L10n::$locales['%d trackbacks'] = '%d enlaces inversos';
L10n::$locales['%s reactions'] = '';
L10n::$locales['Access to content'] = 'Ir al contenido';
L10n::$locales['Add a comment'] = 'Añadir un comentario';
L10n::$locales['Add ping'] = '';
L10n::$locales['Additionnal style directives'] = '';
L10n::$locales['All keywords'] = 'Todas las palabras';
L10n::$locales['Archives'] = 'Archivos';
L10n::$locales['Attachments'] = 'Archivos adjuntos';
L10n::$locales['Best of me'] = 'Destacados';
L10n::$locales['Blog info'] = '';
L10n::$locales['Blog menu'] = 'Ir al menú';
L10n::$locales['By'] = 'Por';
L10n::$locales['By category'] = '';
L10n::$locales['By date'] = '';
L10n::$locales['By tag'] = '';
L10n::$locales['Categories'] = 'Categorías';
L10n::$locales['Comment'] = 'Comentario';
L10n::$locales['Comments'] = 'Comentarios';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = '';
L10n::$locales['Comments feed'] = 'Redifusión de comentarios (feeds)';
L10n::$locales['Continue reading'] = 'Continuar leyendo';
L10n::$locales['Document not found'] = 'Documento no encontrado';
L10n::$locales['Email address'] = 'Dirección de e-mail';
L10n::$locales['Email address is not valid'] = 'Dirección de e-mail no válida';
L10n::$locales['Entries feed'] = 'Redifusión de entradas (feeds)';
L10n::$locales['Explore archives'] = '';
L10n::$locales['Extra menu'] = 'Ir al menú';
L10n::$locales['From'] = '';
L10n::$locales['FromDay'] = '';
L10n::$locales['Go to homepage'] = '';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'El código HTML se reconoce como texto y las direcciones web se transformarán de manera automática.';
L10n::$locales['Home'] = 'Inicio';
L10n::$locales['In'] = '';
L10n::$locales['Languages'] = 'Idiomas';
L10n::$locales['Links'] = 'Enlaces';
L10n::$locales['Name or nickname'] = 'Nombre o alias';
L10n::$locales['Next entry:'] = 'entradas siguientes';
L10n::$locales['On'] = 'El';
L10n::$locales['Page top'] = '';
L10n::$locales['Pagination'] = '';
L10n::$locales['Password needed'] = 'Es necesaria la contraseña';
L10n::$locales['Password:'] = 'Contraseña:';
L10n::$locales['Permalink'] = 'Enlace permanente';
L10n::$locales['Powered by %s'] = 'Impulsado por %s';
L10n::$locales['Preview'] = 'vista previa';
L10n::$locales['Previous entry:'] = 'entradas anteriores';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Una redifusión web o feed (RSS/Atom) es un resumen de contenido de un sitio web. Proporciona contenidos (de entradas y comentarios) o resúmenes de los mismos, junto con enlaces a la versión completa y a cualquier otra información que contenga. De esta manera las ultimas publicaciones del sitio pueden ser leídas por su <a href="http://es.wikipedia.org/wiki/Agregador/">agregador de noticias</a> favorito.';
L10n::$locales['Read'] = 'Leer';
L10n::$locales['Remember me on this blog'] = 'Recordarme en este blog';
L10n::$locales['Required field'] = '';
L10n::$locales['Search'] = 'Búsqueda';
L10n::$locales['Send'] = '';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Simplemente, copia la dirección URL siguiente en tu agregador:';
L10n::$locales['Subcategories'] = 'Subcategorías';
L10n::$locales['Subscribe'] = 'Suscribirse';
L10n::$locales['Subscribe to'] = 'Suscribirse a';
L10n::$locales['Suggestions:'] = '';
L10n::$locales['The document you are looking for does not exist.'] = 'El documento que buscas no existe';
L10n::$locales['The list of recents posts is available'] = '';
L10n::$locales['They posted on the same topic'] = 'Incluidas en el mismo tema';
L10n::$locales['This blog\'s comments Atom feed'] = 'Redifusión Atom de comentarios de este blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Redifusión Atom de comentarios de esta categoría';
L10n::$locales['This category\'s entries Atom feed'] = 'Redifusión Atom de entradas de esta categoría';
L10n::$locales['This post\'s comments Atom feed'] = 'Redifusión Atom de comentarios de esta entrada';
L10n::$locales['This post\'s comments feed'] = 'Redifusión de comentarios de esta entrada';
L10n::$locales['To content'] = 'Ir al contenido';
L10n::$locales['To menu'] = 'Ir al menú';
L10n::$locales['To search'] = 'Ir al buscador';
L10n::$locales['Trackback URL'] = 'URL de enlace inverso';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
L10n::$locales['Use search form'] = '';
L10n::$locales['Website'] = 'Sitio web';
L10n::$locales['What is an RSS feed?'] = '¿Qué es una redifusión web (RSS/Atom)?';
L10n::$locales['You must give a password to access this area.'] = 'Necesitas una contraseña para acceder a este área.';
L10n::$locales['You must provide a comment'] = 'Debe escribir un comentario';
L10n::$locales['You must provide a valid email address.'] = 'Debes indicar una dirección de e-mail válida.';
L10n::$locales['You must provide an author name'] = 'Debes indicar un nombre del autor';
L10n::$locales['Your comment'] = 'Su comentario';
L10n::$locales['Your comment has been published.'] = 'Su comentario ha sido publicado';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Su comentario ha sido enviado y sera revisado para su publicación.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultado.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultados.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Su búsqueda de <em>%1$s</em> no ha devuelto resultados.';
L10n::$locales['by'] = 'por';
L10n::$locales['here'] = '';
L10n::$locales['in'] = '';
L10n::$locales['next entries'] = 'entradas siguientes';
L10n::$locales['no attachments'] = 'sin archivos adjuntos';
L10n::$locales['no comments'] = 'sin comentarios';
L10n::$locales['no reactions'] = '';
L10n::$locales['no trackbacks'] = 'sin enlaces inversos';
L10n::$locales['of'] = 'de';
L10n::$locales['on'] = 'el';
L10n::$locales['one attachment'] = 'un archivo adjunto';
L10n::$locales['one comment'] = 'un comentario';
L10n::$locales['one reaction'] = 'Continuar leyendo';
L10n::$locales['one trackback'] = 'un enlace inverso';
L10n::$locales['optional'] = 'opcional';
L10n::$locales['page'] = 'página';
L10n::$locales['preview'] = 'vista previa';
L10n::$locales['previous entries'] = 'entradas anteriores';
L10n::$locales['reactions'] = '';
L10n::$locales['send'] = 'enviar';
L10n::$locales['toDay'] = '';

==> es-ar-2.27.2.zip: es-ar/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d archivos adjuntos';
L10n::$locales['%d comments'] = '%d comentarios';
L10n::$locales['%d trackbacks'] = '%d enlaces inversos';
L10n::$locales['%s reactions'] = '%s reacciones';
L10n::$locales['Access to content'] = 'Acceso a los contenidos';
L10n::$locales['Add a comment'] = 'Añadir un comentario';
L10n::$locales['Add ping'] = 'Agregar un retroenlace';
L10n::$locales['Additionnal style directives'] = 'Instrucciones CSS adicionales';
L10n::$locales['All keywords'] = 'Todas las palabras';
L10n::$locales['Archives'] = 'Archivos';
L10n::$locales['Attachments'] = 'Archivos adjuntos';
L10n::$locales['Best of me'] = 'Destacados';
L10n::$locales['Blog info'] = 'Información del blog';
L10n::$locales['Blog menu'] = 'Menú del blog';
L10n::$locales['By'] = 'Por';
L10n::$locales['By category'] = 'Por categoría';
L10n::$locales['By date'] = 'Por fecha';
L10n::$locales['By tag'] = 'Por tag';
L10n::$locales['Categories'] = 'Categorías';
L10n::$locales['Comment'] = 'Comentario';
L10n::$locales['Comments'] = 'Comentarios';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Los comentarios pueden formatearse utilizando una sencilla sintaxis wiki.';
L10n::$locales['Comments feed'] = 'Redifusión de comentarios (feeds)';
L10n::$locales['Continue reading'] = 'Continuar leyendo';
L10n::$locales['Document not found'] = 'Documento no encontrado';
L10n::$locales['Email address'] = 'Dirección de e-mail';
L10n::$locales['Email address is not valid'] = 'Dirección de e-mail no válida';
L10n::$locales['Entries feed'] = 'Redifusión de entradas (feeds)';
L10n::$locales['Explore archives'] = 'Explorar los archivos';
L10n::$locales['Extra menu'] = 'Menú extra';
L10n::$locales['From'] = 'Por';
L10n::$locales['FromDay'] = 'Del';
L10n::$locales['Go to homepage'] = 'Regresar al inicio';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'El código HTML se reconoce como texto y las direcciones web se transformarán de manera automática.';
L10n::$locales['Home'] = 'Inicio';
L10n::$locales['In'] = 'En';
L10n::$locales['Languages'] = 'Idiomas';
L10n::$locales['Links'] = 'Enlaces';
L10n::$locales['Name or nickname'] = 'Nombre o alias';
L10n::$locales['Next entry:'] = 'Entrada siguiente:';
L10n::$locales['On'] = 'El';
L10n::$locales['Page top'] = 'Principio de página';
L10n::$locales['Pagination'] = 'Paginación';
L10n::$locales['Password needed'] = 'Es necesaria la contraseña';
L10n::$locales['Password:'] = 'Contraseña:';
L10n::$locales['Permalink'] = 'Enlace permanente';
L10n::$locales['Powered by %s'] = 'Impulsado por %s';
L10n::$locales['Preview'] = 'Vista previa';
L10n::$locales['Previous entry:'] = 'Entrada anterior:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Una redifusión web o feed (RSS/Atom) es un resumen de contenido de un sitio web. Proporciona contenidos (de entradas y comentarios) o resúmenes de los mismos, junto con enlaces a la versión completa y a cualquier otra información que contenga. De esta manera las ultimas publicaciones del sitio pueden ser leídas por su <a href="http://es.wikipedia.org/wiki/Agregador/">agregador de noticias</a> favorito.';
L10n::$locales['Read'] = 'Leer';
L10n::$locales['Remember me on this blog'] = 'Recordarme en este blog';
L10n::$locales['Required field'] = 'Campo obligatorio';
L10n::$locales['Search'] = 'Búsqueda';
L10n::$locales['Send'] = 'Enviar';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Simplemente, copia la dirección URL siguiente en tu agregador:';
L10n::$locales['Subcategories'] = 'Subcategorías';
L10n::$locales['Subscribe'] = 'Suscribirse';
L10n::$locales['Subscribe to'] = 'Suscribirse a';
L10n::$locales['Suggestions:'] = 'Sugerencias:';
L10n::$locales['The document you are looking for does not exist.'] = 'El documento que buscas no existe';
L10n::$locales['The list of recents posts is available'] = 'La lista de entradas recientes está disponible';
L10n::$locales['They posted on the same topic'] = 'Incluidas en el mismo tema';
L10n::$locales['This blog\'s comments Atom feed'] = 'Redifusión Atom de comentarios de este blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Redifusión Atom de comentarios de esta categoría';
L10n::$locales['This category\'s entries Atom feed'] = 'Redifusión Atom de entradas de esta categoría';
L10n::$locales['This post\'s comments Atom feed'] = 'Redifusión Atom de comentarios de esta entrada';
L10n::$locales['This post\'s comments feed'] = 'Redifusión de comentarios de esta entrada';
L10n::$locales['To content'] = 'Ir al contenido';
L10n::$locales['To menu'] = 'Ir al menú';
L10n::$locales['To search'] = 'Ir al buscador';
L10n::$locales['Trackback URL'] = 'URL de enlace inverso';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'Su URL está equivocada o la página fue borrada o desplazada.';
L10n::$locales['Use search form'] = 'Buscar';
L10n::$locales['Website'] = 'Sitio web';
L10n::$locales['What is an RSS feed?'] = '¿Qué es una redifusión web (RSS/Atom)?';
L10n::$locales['You must give a password to access this area.'] = 'Necesitas una contraseña para acceder a este área.';
L10n::$locales['You must provide a comment'] = 'Debe escribir un comentario';
L10n::$locales['You must provide a valid email address.'] = 'Debes indicar una dirección de e-mail válida.';
L10n::$locales['You must provide an author name'] = 'Debes indicar un nombre del autor';
L10n::$locales['Your comment'] = 'Su comentario';
L10n::$locales['Your comment has been published.'] = 'Su comentario ha sido publicado';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Su comentario ha sido enviado y sera revisado para su publicación.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultado.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Su búsqueda de <em>%1$s</em> ha devuelto <strong>%2$s</strong> resultados.';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Su búsqueda de <em>%1$s</em> no ha devuelto resultados.';
L10n::$locales['by'] = 'por';
L10n::$locales['here'] = 'aquí';
L10n::$locales['in'] = 'en';
L10n::$locales['next entries'] = 'entradas siguientes';
L10n::$locales['no attachments'] = 'sin archivos adjuntos';
L10n::$locales['no comments'] = 'ningún comentario';
L10n::$locales['no reactions'] = 'no reacciones';
L10n::$locales['no trackbacks'] = 'sin enlaces inversos';
L10n::$locales['of'] = 'de';
L10n::$locales['on'] = 'el';
L10n::$locales['one attachment'] = 'un archivo adjunto';
L10n::$locales['one comment'] = 'un comentario';
L10n::$locales['one reaction'] = 'una reaccion';
L10n::$locales['one trackback'] = 'un enlace inverso';
L10n::$locales['optional'] = 'opcional';
L10n::$locales['page'] = 'página';
L10n::$locales['preview'] = 'vista previa';
L10n::$locales['previous entries'] = 'entradas anteriores';
L10n::$locales['reactions'] = 'reacciones';
L10n::$locales['send'] = 'enviar';
L10n::$locales['toDay'] = 'al';
